function pileface_naif_auto
% La fonction "pileface_naif_auto" évalue R en ajustant automatiquement le
% nombre de simulations pour obtenir la précision relative "precision"
% définie au début du code.

% Ne pas hésiter à détériorer la valuer de "precision" pour vérifier que le
% programme marche bien, car avec 4 ‰ l'exécution sera très longue.
precision = .004;

% On commence par une évaluation grossière de la moyenne et de
% l'écart-type, à l'aide d'un nombre modéré N0 de simulations, disons
% 10000.

N0 = 10000;
somme = 0;
somme2 = 0;
for i = 1 : N0
    nbpile = 0;
    for j = 1 : 100
        if rand < 1/2
            nbpile = nbpile + 1;
        end
    end
    valeur = max (nbpile - 60, 0);
    somme = somme + valeur;
    somme2 = somme2 + valeur * valeur;
end
moyenne = somme / N0;
ectype = sqrt (somme2/N0 - moyenne*moyenne);

% Maintenant, nous pouvons déterminer la valeur N du nombre de simulations
% requises pour que la demi-largeur de l'intervalle de confiance, à peu
% près égale à 2 * ectype/sqrt(N) (car on peut raisonnablement supposer que
% l'estimateur de l'écart-type obtenu au bout de N0 simulations est déjà
% très proche de l'estimateur final), soit une fraction precision de la
% valeur estimée, laquelle sera à peu égale près à moyenne (même remarque
% que pour la demi-largeur). Pour plus de sécurité, on prend un facteur 1.1
% de marge.

N = 1.1 * (2*ectype / (precision*moyenne))^2;
% On transforme N pour que ce soit un entier et pour qu'il vaille au moins
% N0 : puisqu'on a déjà calculé N0 simulations, autant en prendre compte !
N = max (ceil(N), N0);

% On continue le calcul (en reprenant à la suite des N0 simulations déjà
% effectuées) jusqu'à avoir N simulations (*1). Et là normalement le résultat sera
% bon (*2) !
for i = N0+1 : N
    nbpile = 0;
    for j = 1 : 100
        if rand < 1/2
            nbpile = nbpile + 1;
        end
    end
    valeur = max (nbpile - 60, 0);
    somme = somme + valeur;
    % Noter qu'ici, si on considère que l'estimation de l'écart-type est
    % déjà suffisamment précise au bout de N0 simulations, on peut se
    % dispenser de maintenir "somme2", et utiliser à la fin de la boucle
    % l'estimation initiale de l'écart-type.
    somme2 = somme2 + valeur * valeur;
end

moyenne = somme / N;
ectype = sqrt (somme2/N - moyenne*moyenne);
disp('Évaluation de R :')
fprintf('%.5f ± %.5f\n', moyenne, 2 * ectype/sqrt(N));
end

% (*1) Remarquez que du coup on a de la duplication de code (càd. un long
% passage de code identique ou quasi-identique) entre la première et la
% seconde partie du programme... De manière générale, la duplication de
% code doit être évitée car elle est potentiellement source de bugs (quand
% on oublie de corriger une des occurrences du code dupliqué). Cela dit,
% pour ne pas dupliquer le code ici il aurait fallu rajouter des conditions
% "if" qui auraient un peu ralenti l'exécution — ici ladite perte de temps
% aurait été négligeable, mais c'est juste pour dire que dans certains cas
% la duplication de code peut être justifiée (sans compter que parfois pour
% ne pas dupliquer un code on se retrouve à devoir le rendre plus
% compliqué, et cela est aussi potentiellement source de perte de temps ou
% de bugs...).
%
% Ici en fait, non seulement on n'avait pas réellement besoin du dupliquer
% le code pour gagner du temps, mais la perte de temps aurait été tout
% aussi négligeable si on avait vérifié au fur et à mesure si la précision
% requise était atteinte ! Bref, cette question est surtout pédagogique,
% pour montrer que dans un calcul de Monte-Carlo, on peut prévoir à
% l'avance la quantité de calculs requise pour atteindre une certaine
% précision...

% (*2) On pourrait rajouter quelques lignes pour vérifier si la précision
% demandée a effectivement été atteinte, et pour poursuivre encore un peu
% le calcul si par malchance ce n'était pas le cas ; mais comme la
% philosophie de cette question est justement de dire qu'on sait prévoir à
% l'avance la quantité de simulations requises, ce serait un peu idiot de
% le faire... Et de fait, le programme marchera parfaitement bien en
% pratique !