function pileface_pref (N)
% La fonction "pileface_pref" évalue R à l'aide de N simulations, en
% utilisant l'échantillonnage préférentiel suggéré par l'énoncé. Je ne
% commente que les différences.

% "biais" est le paramètre de biais de la pièce dans l'échantillonnage
% préférentiel. Ainsi, juste en changeant cette ligne, vous pourrez
% regarder ce que cela aurait donné avec d'autres paramètres pour
% l'échantillonnage.
biais = .6;

somme = 0;
somme2 = 0;
for i = 1 : N
    nbpile = 0;
    % Cette fois il va aussi falloir maintenir à jour la densité "densite"
    % de la vraie loi par rapport à la loi d'échantillonnage préférentiel.
    % (*1)
    densite = 1;
    for j = 1 : 100
        % Cette fois-ci dans le simulations qu'on fait, “pile” a biais
        % chances de sortir.
        if rand < biais
            nbpile = nbpile + 1;
            % On met à jour la densité dans le cas où “pile” est sorti :
            % cela avait biais chances de se produire sous notre
            % échantillonnage préférentiel, mais seulement une chance sur
            % deux sous la vraie densité, d'où une densité relative de
            % (1/2) / biais.
            densite = densite * (1/2) / biais;
        else
            % Attention, cette fois-ci il faut aussi tenir compte du cas où
            % la pièce retombe sur "face" : si cela ne change toujours pas
            % la valeur de "nbpile", en revanche il faut maintenant penser
            % à maintenir à jour la densité.
            densite = densite * (1/2) / (1-biais);
        end
    end
    % Maintenant "valeur" doit aussi tenir compte de la densité !
    valeur = densite * max (nbpile - 60, 0);
    somme = somme + valeur;
    somme2 = somme2 + valeur * valeur;
end

moyenne = somme / N;
ectype = sqrt (somme2/N - moyenne*moyenne);
disp('Évaluation de R :')
fprintf('%.5f ± %.5f\n', moyenne, 2 * ectype/sqrt(N));
end

% (*1) Dans ce cas particulier, on pourrait facilement calculer
% théoriquement les lois d'échantillonnage ; et il se trouve qu'alors il y
% aurait une formule particulièrement simple pour la densité, à savoir 1 /
% ((2*biais)^nbpile * (2*(1-biais))^nbpile). Cela aurait donné une
% implémentation un poil plus rapide... Toutefois, je vous conseille de
% vous habituer directement à utiliser la technique générale de calcul de
% la densité par multiplication successive des densités relatives des
% diffférents tirages indépendants effectués, car dans la majorité des cas
% il n'y a que cette technique qu'on puisse utiliser !